@@ -6,6 +6,9 @@ import unicodedata
 import string
 from lxml.cssselect import CSSSelector
 from lxml import etree
+from six import string_types, text_type
+from sys import version_info
+
 
 class Parser(object):
     """ Simple wrapper around lxml object """
@@ -113,9 +116,12 @@ def str2int(string_with_int):
 
 def to_unicode(obj, encoding='utf-8'):
     """ Convert string to unicode string """
-    if isinstance(obj, basestring):
-        if not isinstance(obj, unicode):
-            obj = unicode(obj, encoding)
+    if isinstance(obj, string_types):
+        if not isinstance(obj, text_type):
+            if version_info == 2:
+                obj = unicode(obj)
+                return obj
+            obj = obj.encode(encoding)
     return obj
 
 
